@@ -191,9 +191,8 @@ LTTNG_TRACEPOINT_EVENT(btrfs_get_extent,
 		ctf_integer(u64, ino, btrfs_ino(inode))
 		ctf_integer(u64, start, map->start)
 		ctf_integer(u64, len, map->len)
-		ctf_integer(unsigned int, flags, map->flags)
+		ctf_integer(u32, flags, map->flags)
 		ctf_integer(int, refs, refcount_read(&map->refs))
-		ctf_integer(unsigned int, compress_type, extent_map_compression(map))
 	)
 )
 
@@ -214,9 +213,8 @@ LTTNG_TRACEPOINT_EVENT(btrfs_get_extent,
 		ctf_integer(u64, orig_start, map->orig_start)
 		ctf_integer(u64, block_start, map->block_start)
 		ctf_integer(u64, block_len, map->block_len)
-		ctf_integer(unsigned int, flags, map->flags)
+		ctf_integer(u32, flags, map->flags)
 		ctf_integer(int, refs, refcount_read(&map->refs))
-		ctf_integer(unsigned int, compress_type, extent_map_compression(map))
 	)
 )
 
@@ -706,7 +704,80 @@ LTTNG_TRACEPOINT_EVENT(btrfs_writepage_end_io_hook,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
+
+	TP_PROTO(const struct folio *folio, const struct inode *inode,
+		 const struct writeback_control *wbc),
+
+	TP_ARGS(folio, inode, wbc),
+
+	TP_FIELDS(
+		ctf_integer(ino_t, ino, inode->i_ino)
+		ctf_integer(pgoff_t, index, folio->index)
+		ctf_integer(long, nr_to_write, wbc->nr_to_write)
+		ctf_integer(long, pages_skipped, wbc->pages_skipped)
+		ctf_integer(loff_t, range_start, wbc->range_start)
+		ctf_integer(loff_t, range_end, wbc->range_end)
+		ctf_integer(char, for_kupdate, wbc->for_kupdate)
+		ctf_integer(char, range_cyclic, wbc->range_cyclic)
+		ctf_integer(pgoff_t, writeback_index,
+				inode->i_mapping->writeback_index)
+		ctf_integer(u64, root_objectid,
+				BTRFS_I(inode)->root->root_key.objectid)
+	)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs__writepage,
+
+	__extent_writepage,
+
+	btrfs__extent_writepage,
+
+	TP_PROTO(const struct folio *folio, const struct inode *inode,
+		 const struct writeback_control *wbc),
+
+	TP_ARGS(folio, inode, wbc)
+)
+
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,12,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
+
+	TP_PROTO(const struct folio *folio, const struct inode *inode,
+		 const struct writeback_control *wbc),
+
+	TP_ARGS(folio, inode, wbc),
+
+	TP_FIELDS(
+		ctf_integer(ino_t, ino, inode->i_ino)
+		ctf_integer(pgoff_t, index, folio->index)
+		ctf_integer(long, nr_to_write, wbc->nr_to_write)
+		ctf_integer(long, pages_skipped, wbc->pages_skipped)
+		ctf_integer(loff_t, range_start, wbc->range_start)
+		ctf_integer(loff_t, range_end, wbc->range_end)
+		ctf_integer(char, for_kupdate, wbc->for_kupdate)
+		ctf_integer(char, for_reclaim, wbc->for_reclaim)
+		ctf_integer(char, range_cyclic, wbc->range_cyclic)
+		ctf_integer(pgoff_t, writeback_index,
+				inode->i_mapping->writeback_index)
+		ctf_integer(u64, root_objectid,
+				BTRFS_I(inode)->root->root_key.objectid)
+	)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs__writepage,
+
+	__extent_writepage,
+
+	btrfs__extent_writepage,
+
+	TP_PROTO(const struct folio *folio, const struct inode *inode,
+		 const struct writeback_control *wbc),
+
+	TP_ARGS(folio, inode, wbc)
+)
+
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,73,5,0,0, 4,4,73,6,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,82,6,0,0, 4,4,82,7,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,92,6,0,0, 4,4,92,7,0,0) || \
@@ -747,20 +818,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs__writepage,
 	TP_ARGS(page, inode, wbc)
 )
 
-LTTNG_TRACEPOINT_EVENT(btrfs_sync_file,
-
-	TP_PROTO(const struct file *file, int datasync),
-
-	TP_ARGS(file, datasync),
-
-	TP_FIELDS(
-		ctf_integer(ino_t, ino, file->f_path.dentry->d_inode->i_ino)
-		ctf_integer(ino_t, parent, file->f_path.dentry->d_parent->d_inode->i_ino)
-		ctf_integer(int, datasync, datasync)
-		ctf_integer(u64, root_objectid,
-			BTRFS_I(file->f_path.dentry->d_inode)->root->root_key.objectid)
-	)
-)
 #else
 LTTNG_TRACEPOINT_EVENT_CLASS(btrfs__writepage,
 
@@ -800,7 +857,28 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(btrfs__writepage,
 
 	TP_ARGS(page, inode, wbc)
 )
+#endif
 
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
+	LTTNG_SLE_KERNEL_RANGE(4,4,73,5,0,0, 4,4,73,6,0,0) || \
+	LTTNG_SLE_KERNEL_RANGE(4,4,82,6,0,0, 4,4,82,7,0,0) || \
+	LTTNG_SLE_KERNEL_RANGE(4,4,92,6,0,0, 4,4,92,7,0,0) || \
+	LTTNG_SLE_KERNEL_RANGE(4,4,103,6,0,0, 4,5,0,0,0,0))
+LTTNG_TRACEPOINT_EVENT(btrfs_sync_file,
+
+	TP_PROTO(const struct file *file, int datasync),
+
+	TP_ARGS(file, datasync),
+
+	TP_FIELDS(
+		ctf_integer(ino_t, ino, file->f_path.dentry->d_inode->i_ino)
+		ctf_integer(ino_t, parent, file->f_path.dentry->d_parent->d_inode->i_ino)
+		ctf_integer(int, datasync, datasync)
+		ctf_integer(u64, root_objectid,
+			BTRFS_I(file->f_path.dentry->d_inode)->root->root_key.objectid)
+	)
+)
+#else
 LTTNG_TRACEPOINT_EVENT(btrfs_sync_file,
 
 	TP_PROTO(struct file *file, int datasync),
@@ -1922,7 +2000,25 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__chunk,  btrfs_chunk_free,
 
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0) || \
+	LTTNG_KERNEL_RANGE(6,16,4, 6,17,0))
+LTTNG_TRACEPOINT_EVENT(btrfs_cow_block,
+
+	TP_PROTO(const struct btrfs_root *root, const struct extent_buffer *buf,
+		 const struct extent_buffer *cow),
+
+	TP_ARGS(root, buf, cow),
+
+	TP_FIELDS(
+		ctf_integer(u64, root_objectid, root->root_key.objectid)
+		ctf_integer(u64, buf_start, buf->start)
+		ctf_integer(int, refs, refcount_read(&buf->refs))
+		ctf_integer(u64, cow_start, cow->start)
+		ctf_integer(int, buf_level, btrfs_header_level(buf))
+		ctf_integer(int, cow_level, btrfs_header_level(cow))
+	)
+)
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,73,5,0,0, 4,4,73,6,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,82,6,0,0, 4,4,82,7,0,0) || \
 	LTTNG_SLE_KERNEL_RANGE(4,4,92,6,0,0, 4,4,92,7,0,0) || \
@@ -2135,7 +2231,24 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(btrfs__reserved_extent,  btrfs_reserved_extent_f
 
 #endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,10,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,16,0))
+LTTNG_TRACEPOINT_EVENT(btrfs_find_free_extent,
+
+	TP_PROTO(const struct btrfs_root *root,
+		const struct find_free_extent_ctl *ffe_ctl),
+
+	TP_ARGS(root, ffe_ctl),
+
+	TP_FIELDS(
+		ctf_array(u8, fsid, root->lttng_fs_info_fsid, BTRFS_UUID_SIZE)
+		ctf_integer(u64, root_objectid, root->root_key.objectid)
+		ctf_integer(u64, num_bytes, ffe_ctl->num_bytes)
+		ctf_integer(u64, empty_size, ffe_ctl->empty_size)
+		ctf_integer(u64, flags, ffe_ctl->flags)
+	)
+)
+
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,3,0))
 LTTNG_TRACEPOINT_EVENT_MAP(find_free_extent,
 
 	btrfs_find_free_extent,
