@@ -117,79 +117,79 @@ static const struct lttng_kernel_event_field *emptyfields[] = {
 static const struct lttng_kernel_event_field *tcpfields[] = {
 	[0] = lttng_kernel_static_event_field("source_port",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("dest_port",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("seq",
 		lttng_kernel_static_type_integer_from_type(uint32_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[3] = lttng_kernel_static_event_field("ack_seq",
 		lttng_kernel_static_type_integer_from_type(uint32_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[4] = lttng_kernel_static_event_field("data_offset",
 		lttng_kernel_static_type_integer(4, 4, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[5] = lttng_kernel_static_event_field("reserved",
 		lttng_kernel_static_type_integer(3, 1, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[6] = lttng_kernel_static_event_field("flags",
 		lttng_kernel_static_type_integer(9, 1, 0, __BIG_ENDIAN, 16),
-		false, false, false),
+		false, false),
 	[7] = lttng_kernel_static_event_field("window_size",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[8] = lttng_kernel_static_event_field("checksum",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 16),
-		false, false, false),
+		false, false),
 	[9] = lttng_kernel_static_event_field("urg_ptr",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_event_field *udpfields[] = {
 	[0] = lttng_kernel_static_event_field("source_port",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("dest_port",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("len",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[3] = lttng_kernel_static_event_field("check",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_event_field *icmpfields[] = {
 	[0] = lttng_kernel_static_event_field("type",
 		lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("code",
 		lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("checksum",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[3] = lttng_kernel_static_event_field("gateway",
 		lttng_kernel_static_type_integer_from_type(uint32_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_event_field *transport_fields[] = {
 	[0] = lttng_kernel_static_event_field("unknown",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(emptyfields), emptyfields, 0),
-		false, false, true),
+		false, true),
 	[1] = lttng_kernel_static_event_field("tcp",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(tcpfields), tcpfields, 0),
-		false, false, true),
+		false, true),
 	[2] = lttng_kernel_static_event_field("udp",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(udpfields), udpfields, 0),
-		false, false, true),
+		false, true),
 	[3] = lttng_kernel_static_event_field("icmp",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(icmpfields), icmpfields, 0),
-		false, false, true),
+		false, true),
 };
 
 #endif /* LTTNG_CREATE_FIELD_METADATA */
@@ -222,98 +222,98 @@ LTTNG_TRACEPOINT_ENUM(transport_header_type,
 static const struct lttng_kernel_event_field *ipv4fields[] = {
 	[0] = lttng_kernel_static_event_field("version",
 		lttng_kernel_static_type_integer(4, 4, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("ihl",
 		lttng_kernel_static_type_integer(4, 4, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("tos",
 		lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[3] = lttng_kernel_static_event_field("tot_len",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[4] = lttng_kernel_static_event_field("id",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 16),
-		false, false, false),
+		false, false),
 	[5] = lttng_kernel_static_event_field("frag_off",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[6] = lttng_kernel_static_event_field("ttl",
 		lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[7] = lttng_kernel_static_event_field("protocol",
 		lttng_kernel_static_type_enum(&__enum_proto_transport_header_type,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10)),
-		false, false, false),
+		false, false),
 	[8] = lttng_kernel_static_event_field("checksum",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 16),
-		false, false, false),
+		false, false),
 	[9] = lttng_kernel_static_event_field("saddr",
 		lttng_kernel_static_type_array(4,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
 			lttng_alignof(uint8_t), none),
-		false, false, false),
+		false, false),
 	[10] = lttng_kernel_static_event_field("daddr",
 		lttng_kernel_static_type_array(4,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
 			lttng_alignof(uint8_t), none),
-		false, false, false),
+		false, false),
 	[11] = lttng_kernel_static_event_field("transport_header_type",
 		lttng_kernel_static_type_enum(&__enum_transport_header_type,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BYTE_ORDER, 10)),
-		false, false, false),
+		false, false),
 	[12] = lttng_kernel_static_event_field("transport_header",
 		lttng_kernel_static_type_variant(ARRAY_SIZE(transport_fields), transport_fields,
 			NULL, 0),	/* Previous field as tag. */
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_event_field *ipv6fields[] = {
 	[0] = lttng_kernel_static_event_field("version",
 		lttng_kernel_static_type_integer(4, 4, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("prio",
 		lttng_kernel_static_type_integer(4, 4, 0, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("flow_lbl",
 		lttng_kernel_static_type_array(3, lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 16), lttng_alignof(uint8_t), none),
-		false, false, false),
+		false, false),
 	[3] = lttng_kernel_static_event_field("payload_len",
 		lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[4] = lttng_kernel_static_event_field("nexthdr",
 		lttng_kernel_static_type_enum(&__enum_proto_transport_header_type,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10)),
-		false, false, false),
+		false, false),
 	[5] = lttng_kernel_static_event_field("hop_limit",
 		lttng_kernel_static_type_integer_from_type(uint8_t, __BIG_ENDIAN, 10),
-		false, false, false),
+		false, false),
 	[6] = lttng_kernel_static_event_field("saddr",
 		lttng_kernel_static_type_array(8, lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 16), lttng_alignof(uint16_t), none),
-		false, false, false),
+		false, false),
 	[7] = lttng_kernel_static_event_field("daddr",
 		lttng_kernel_static_type_array(8, lttng_kernel_static_type_integer_from_type(uint16_t, __BIG_ENDIAN, 16), lttng_alignof(uint16_t), none),
-		false, false, false),
+		false, false),
 	[8] = lttng_kernel_static_event_field("transport_header_type",
 		lttng_kernel_static_type_enum(&__enum_transport_header_type,
 			lttng_kernel_static_type_integer_from_type(uint8_t, __BYTE_ORDER, 10)),
-		false, false, false),
+		false, false),
 	[9] = lttng_kernel_static_event_field("transport_header",
 		lttng_kernel_static_type_variant(ARRAY_SIZE(transport_fields),
 			transport_fields, NULL, 0),	/* Previous field as tag. */
-		false, false, false),
+		false, false),
 };
 
 static const struct lttng_kernel_event_field *network_fields[] = {
 	[0] = lttng_kernel_static_event_field("unknown",
 		lttng_kernel_static_type_struct(0, emptyfields, 0),
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("ipv4",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(ipv4fields), ipv4fields, 0),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("ipv6",
 		lttng_kernel_static_type_struct(ARRAY_SIZE(ipv6fields), ipv6fields, 0),
-		false, false, false),
+		false, false),
 };
 
 #endif /* LTTNG_CREATE_FIELD_METADATA */
