@@ -144,6 +144,62 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 
 #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0))
 
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,16,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(writeback_folio_template,
+
+	TP_PROTO(struct folio *folio, struct address_space *mapping),
+
+	TP_ARGS(folio, mapping),
+
+	TP_FIELDS(
+		ctf_string(name, lttng_bdi_dev_name(mapping ? inode_to_bdi(mapping->host) : NULL))
+		ctf_integer(unsigned long, ino, (mapping && mapping->host) ? mapping->host->i_ino : 0)
+		ctf_integer(pgoff_t, index, folio->index)
+	)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_folio_template, writeback_dirty_folio,
+
+	TP_PROTO(struct folio *folio, struct address_space *mapping),
+
+	TP_ARGS(folio, mapping)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_folio_template, folio_wait_writeback,
+
+	TP_PROTO(struct folio *folio, struct address_space *mapping),
+
+	TP_ARGS(folio, mapping)
+)
+
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,2,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(writeback_page_template,
+
+	TP_PROTO(struct page *page, struct address_space *mapping),
+
+	TP_ARGS(page, mapping),
+
+	TP_FIELDS(
+		ctf_string(name, lttng_bdi_dev_name(mapping ? inode_to_bdi(mapping->host) : NULL))
+		ctf_integer(unsigned long, ino, (mapping && mapping->host) ? mapping->host->i_ino : 0)
+		ctf_integer(pgoff_t, index, page->index)
+	)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_page_template, writeback_dirty_page,
+
+	TP_PROTO(struct page *page, struct address_space *mapping),
+
+	TP_ARGS(page, mapping)
+)
+
+LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_page_template, wait_on_page_writeback,
+
+	TP_PROTO(struct page *page, struct address_space *mapping),
+
+	TP_ARGS(page, mapping)
+)
+#else
 LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 	TP_PROTO(struct page *page, struct address_space *mapping),
 	TP_ARGS(page, mapping),
@@ -153,6 +209,7 @@ LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 		ctf_integer(pgoff_t, index, page->index)
 	)
 )
+#endif
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_dirty_inode_template,
 	TP_PROTO(struct inode *inode, int flags),
@@ -373,6 +430,23 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_written,
 )
 #endif
 
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(6,17,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
+	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
+	TP_ARGS(wbc, bdi),
+	TP_FIELDS(
+		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_integer(long, nr_to_write, wbc->nr_to_write)
+		ctf_integer(long, pages_skipped, wbc->pages_skipped)
+		ctf_integer(int, sync_mode, wbc->sync_mode)
+		ctf_integer(int, for_kupdate, wbc->for_kupdate)
+		ctf_integer(int, for_background, wbc->for_background)
+		ctf_integer(int, range_cyclic, wbc->range_cyclic)
+		ctf_integer(long, range_start, (long) wbc->range_start)
+		ctf_integer(long, range_end, (long) wbc->range_end)
+	)
+)
+#else
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
 	TP_ARGS(wbc, bdi),
@@ -394,6 +468,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 		ctf_integer(long, range_end, (long) wbc->range_end)
 	)
 )
+#endif
 
 #undef DEFINE_WBC_EVENT
 #define LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(name, map) \
